# Changelog

## [Unreleased]

## [0.0.7] - 2021-01-31
* added Tumblr (default theme) and Yandex.Market

## [0.0.6] - 2021-01-31
* updated Yandex services extractors (again)

## [0.0.5] - 2021-01-31
* updated Yandex services extractors

## [0.0.4] - 2021-01-16
* actualized Vimeo and VK

## [0.0.3] - 2021-01-15
* actualized Twitter
